@@ -13,18 +13,18 @@
 #include <QIcon>
 
 #include "kamoso_version.h"
+#include <gst/gst.h>
 
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps);
     KLocalizedString::setApplicationDomain("kamoso");
     {
-        KAboutData about("kamoso", i18n("Kamoso"), KAMOSO_VERSION_STRING, i18n("Utility for taking photos and videos using a webcam"),
+        KAboutData about(QStringLiteral("kamoso"), i18n("Kamoso"), QStringLiteral(KAMOSO_VERSION_STRING), i18n("Utility for taking photos and videos using a webcam"),
                          KAboutLicense::GPL, i18n("(C) 2008-2015 Alex Fiestas and Aleix Pol"));
 
-        about.addAuthor( i18n("Aleix Pol Gonzalez"), i18n("Semaphore hacker"), "aleixpol@kde.org" );
-        about.addAuthor( i18n("Alex Fiestas"), i18n("Coffee drinker"), "afiestas@kde.org" );
+        about.addAuthor( i18n("Aleix Pol Gonzalez"), i18n("Semaphore hacker"), QStringLiteral("aleixpol@kde.org"));
+        about.addAuthor( i18n("Alex Fiestas"), i18n("Coffee drinker"), QStringLiteral("afiestas@kde.org"));
         about.addCredit( i18n("caseymoura"), i18n("Uploaded the shutter sound: https://freesound.org/people/caseymoura/sounds/445482/"), {} );
         KAboutData::setApplicationData(about);
         QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kamoso"), app.windowIcon()));
@@ -35,13 +35,14 @@ int main(int argc, char *argv[])
         about.processCommandLine(&parser);
     }
 
-    WebcamControl webcamControl;
-    if (!webcamControl.play()) {
-        qWarning("Unrecoverable error occurred when initializing webcam. Exiting.");
-        QApplication::exit(1);
-        return 1;
+    // Ensure it's loaded so the QML module is registered =.=
+    {
+        gst_init(NULL, NULL);
+        GstPointer<GstElement> qmlglsink;
+        qmlglsink.reset(gst_element_factory_make("qml6glsink", ""));
     }
 
+    WebcamControl webcamControl;
     QObject::connect(&app, &QCoreApplication::aboutToQuit, &webcamControl, &WebcamControl::stop);
 
     return app.exec();
